summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--xmake/core/project/project.lua12
1 files changed, 6 insertions, 6 deletions
diff --git a/xmake/core/project/project.lua b/xmake/core/project/project.lua
index 946ec5ecc..e20884f54 100644
--- a/xmake/core/project/project.lua
+++ b/xmake/core/project/project.lua
@@ -306,7 +306,7 @@ function project.get(name)
end
-- load the project file
-function project._load(force)
+function project._load(force, disable_filter)
-- has already been loaded?
if project._INFO and not force then
@@ -329,13 +329,13 @@ function project._load(force)
end
-- load the root info of the project
- local rootinfo, errors = project._load_scope("root", true, true)
+ local rootinfo, errors = project._load_scope("root", true, not disable_filter)
if not rootinfo then
return false, errors
end
-- load the root info of the target
- local rootinfo_target, errors = project._load_scope("root.target", true, true)
+ local rootinfo_target, errors = project._load_scope("root.target", true, not disable_filter)
if not rootinfo_target then
return false, errors
end
@@ -412,8 +412,8 @@ function project._load_tasks()
return {}, nil
end
- -- load the project file first
- local ok, errors = project._load(true)
+ -- load the project file first and disable filter
+ local ok, errors = project._load(true, true)
if not ok then
return nil, errors
end
@@ -571,7 +571,7 @@ function project._load_options(disable_filter)
end
-- reload the project file to ensure `if is_plat() then add_packagedirs() end` works
- local ok, errors = project._load(true)
+ local ok, errors = project._load(true, disable_filter)
if not ok then
return nil, errors
end